@@ -21,6 +21,9 @@ impl XXError {
 
 impl From<XXError> for Error {
     fn from(err: XXError) -> Self {
-        Self::new(XXError::DOMAIN_CODE + (err as u32), XXError::DOMAIN_NAME)
+        Self::new(
+            XXError::DOMAIN_CODE + (err as u32),
+            ockam_core::compat::format!("{}::{:?}", module_path!(), err),
+        )
     }
 }
